@@ -25,16 +25,10 @@ import org.apache.spark.sql.sources._
 import org.slf4j.Logger
 
 import java.sql.{Date, Timestamp}
-import java.time.Duration
-import java.util.concurrent.locks.LockSupport
-import scala.annotation.tailrec
-import scala.reflect.ClassTag
-import scala.util.{Failure, Success, Try}
 
-private[spark] object Utils {
+private[sql] object Utils {
   /**
    * quote column name
-   *
    * @param colName column name
    * @return quoted column name
    */
@@ -42,9 +36,8 @@ private[spark] object Utils {
 
   /**
    * compile a filter to Doris FE filter format.
-   *
-   * @param filter             filter to be compile
-   * @param dialect            jdbc dialect to translate value to sql format
+   * @param filter filter to be compile
+   * @param dialect jdbc dialect to translate value to sql format
    * @param inValueLengthLimit max length of in value array
    * @return if Doris FE can handle this filter, return None if Doris FE can not handled it.
    */
@@ -61,12 +54,6 @@ private[spark] object Utils {
         } else {
           s"${quote(attribute)} in (${compileValue(values)})"
         }
-      case Not(In(attribute, values)) =>
-        if (values.isEmpty || values.length >= inValueLengthLimit) {
-          null
-        } else {
-          s"${quote(attribute)} not in (${compileValue(values)})"
-        }
       case IsNull(attribute) => s"${quote(attribute)} is null"
       case IsNotNull(attribute) => s"${quote(attribute)} is not null"
       case And(left, right) =>
@@ -89,7 +76,6 @@ private[spark] object Utils {
 
   /**
    * Escape special characters in SQL string literals.
-   *
    * @param value The string to be escaped.
    * @return Escaped string.
    */
@@ -98,7 +84,6 @@ private[spark] object Utils {
 
   /**
    * Converts value to SQL expression.
-   *
    * @param value The value to be converted.
    * @return Converted value.
    */
@@ -112,20 +97,13 @@ private[spark] object Utils {
 
   /**
    * check parameters validation and process it.
-   *
    * @param parameters parameters from rdd and spark conf
-   * @param logger     slf4j logger
+   * @param logger slf4j logger
    * @return processed parameters
    */
   def params(parameters: Map[String, String], logger: Logger) = {
     // '.' seems to be problematic when specifying the options
-    val dottedParams = parameters.map { case (k, v) =>
-      if (k.startsWith("sink.properties.") || k.startsWith("doris.sink.properties.")) {
-        (k, v)
-      } else {
-        (k.replace('_', '.'), v)
-      }
-    }
+    val dottedParams = parameters.map { case (k, v) => (k.replace('_', '.'), v)}
 
     val preferredTableIdentifier = dottedParams.get(ConfigurationOptions.DORIS_TABLE_IDENTIFIER)
       .orElse(dottedParams.get(ConfigurationOptions.TABLE_IDENTIFIER))
@@ -146,7 +124,7 @@ private[spark] object Utils {
       case (k, v) =>
         if (k.startsWith("doris.")) (k, v)
         else ("doris." + k, v)
-    }.map {
+    }.map{
       case (ConfigurationOptions.DORIS_REQUEST_AUTH_PASSWORD, _) =>
         logger.error(s"${ConfigurationOptions.DORIS_REQUEST_AUTH_PASSWORD} cannot use in Doris Datasource.")
         throw new DorisException(s"${ConfigurationOptions.DORIS_REQUEST_AUTH_PASSWORD} cannot use in" +
@@ -170,27 +148,8 @@ private[spark] object Utils {
 
     // validate path is available
     finalParams.getOrElse(ConfigurationOptions.DORIS_TABLE_IDENTIFIER,
-      throw new DorisException("table identifier must be specified for doris table identifier."))
+        throw new DorisException("table identifier must be specified for doris table identifier."))
 
     finalParams
   }
-
-  @tailrec
-  def retry[R, T <: Throwable : ClassTag](retryTimes: Int, interval: Duration, logger: Logger)
-                                         (f: => R)(h: => Unit): Try[R] = {
-    assert(retryTimes >= 0)
-    val result = Try(f)
-    result match {
-      case Success(result) =>
-        LockSupport.parkNanos(interval.toNanos)
-        Success(result)
-      case Failure(exception: T) if retryTimes > 0 =>
-        logger.warn(s"Execution failed caused by: ", exception)
-        logger.warn(s"$retryTimes times retry remaining, the next attempt will be in ${interval.toMillis} ms")
-        LockSupport.parkNanos(interval.toNanos)
-        h
-        retry(retryTimes - 1, interval, logger)(f)(h)
-      case Failure(exception) => Failure(exception)
-    }
-  }
 }
